pub struct IteratorGetResponse {
pub entries: Vec<String>,
}Fields
entries: Vec<String>Trait Implementations
Sourceimpl Clone for IteratorGetResponse
impl Clone for IteratorGetResponse
Sourcefn clone(&self) -> IteratorGetResponse
fn clone(&self) -> IteratorGetResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CompatFrom<IteratorGetResponse> for IteratorGetResponse
impl CompatFrom<IteratorGetResponse> for IteratorGetResponse
Sourcefn compat_from(value: IteratorGetResponse) -> Self
fn compat_from(value: IteratorGetResponse) -> Self
Converts
value into a value of this type.Sourceimpl CompatFrom<IteratorGetResponse> for IteratorGetResponse
impl CompatFrom<IteratorGetResponse> for IteratorGetResponse
Sourcefn compat_from(value: IteratorGetResponse) -> Self
fn compat_from(value: IteratorGetResponse) -> Self
Converts
value into a value of this type.Sourceimpl Debug for IteratorGetResponse
impl Debug for IteratorGetResponse
Sourceimpl<'a, ___E> Encode<IteratorGetResponse<'static>, ___E> for &'a IteratorGetResponsewhere
___E: InternalHandleEncoder + ?Sized + Encoder,
impl<'a, ___E> Encode<IteratorGetResponse<'static>, ___E> for &'a IteratorGetResponsewhere
___E: InternalHandleEncoder + ?Sized + Encoder,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<IteratorGetResponse<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<IteratorGetResponse<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<IteratorGetResponse<'static>, ___E> for IteratorGetResponsewhere
___E: InternalHandleEncoder + ?Sized + Encoder,
impl<___E> Encode<IteratorGetResponse<'static>, ___E> for IteratorGetResponsewhere
___E: InternalHandleEncoder + ?Sized + Encoder,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<IteratorGetResponse<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<IteratorGetResponse<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> EncodeOption<Box<'static, IteratorGetResponse<'static>>, ___E> for &'a IteratorGetResponse
impl<'a, ___E> EncodeOption<Box<'static, IteratorGetResponse<'static>>, ___E> for &'a IteratorGetResponse
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, IteratorGetResponse<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, IteratorGetResponse<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, IteratorGetResponse<'static>>, ___E> for IteratorGetResponse
impl<___E> EncodeOption<Box<'static, IteratorGetResponse<'static>>, ___E> for IteratorGetResponse
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, IteratorGetResponse<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, IteratorGetResponse<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'de> FromWire<IteratorGetResponse<'de>> for IteratorGetResponse
impl<'de> FromWire<IteratorGetResponse<'de>> for IteratorGetResponse
Sourcefn from_wire(wire: IteratorGetResponse<'de>) -> Self
fn from_wire(wire: IteratorGetResponse<'de>) -> Self
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl<'de> FromWireRef<IteratorGetResponse<'de>> for IteratorGetResponse
impl<'de> FromWireRef<IteratorGetResponse<'de>> for IteratorGetResponse
Sourcefn from_wire_ref(wire: &IteratorGetResponse<'de>) -> Self
fn from_wire_ref(wire: &IteratorGetResponse<'de>) -> Self
Converts the given reference to this type.
Sourceimpl Hash for IteratorGetResponse
impl Hash for IteratorGetResponse
Sourceimpl Ord for IteratorGetResponse
impl Ord for IteratorGetResponse
Sourcefn cmp(&self, other: &IteratorGetResponse) -> Ordering
fn cmp(&self, other: &IteratorGetResponse) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for IteratorGetResponse
impl PartialEq for IteratorGetResponse
Sourceimpl PartialOrd for IteratorGetResponse
impl PartialOrd for IteratorGetResponse
impl Eq for IteratorGetResponse
impl StructuralPartialEq for IteratorGetResponse