Iterator

pub struct Iterator;
The type corresponding to the Iterator protocol. An iterator for the key-value store. Note that this protocol makes no guarantee of atomicity - the values may change between pulls from the iterator. Unlike the Store protocol above, this protocol is not @discoverable: it is not independently published by the component that implements it, but rather must have one of its two protocol ends transmitted over an existing FIDL connection.

As is often the case with iterators, the client indicates that they are done with an instance of the iterator by simply closing their end of the connection.

Since the iterator is associated only with the Iterate method, it is declared as closed rather than open. This is because changes to how iteration works are more likely to require replacing the Iterate method completely (which is fine because that method is flexible) rather than evolving the Iterator protocol.