IteratorLocalServerHandler

Trait IteratorLocalServerHandler 

pub trait IteratorLocalServerHandler<___T: Transport = Channel> {
    // Required method
    fn get(
        &mut self,
        responder: Responder<Get, ___T>,
    ) -> impl Future<Output = ()>;
}
A server handler for the Iterator protocol.

See Iterator for more details.

Required Methods

fn get(&mut self, responder: Responder<Get, ___T>) -> impl Future<Output = ()>

Gets the next batch of keys.

The client pulls keys rather than having the server proactively push them, to implement flow control over the messages.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementations on Foreign Types

Source

impl<___H, ___T> IteratorLocalServerHandler<___T> for Local<___H>
where ___H: IteratorServerHandler<___T>, ___T: Transport,

Source

async fn get(&mut self, responder: Responder<Get, ___T>)

Implementors